@@ -17,6 +17,17 @@ head(ic20)
 ## -----------------------------------------------------------------------------
 list.ccurves()
 
+## -----------------------------------------------------------------------------
+intcal <- intcal.read.data()
+IrishOaks <- intcal.data.frames(intcal, taxon="Quercus sp.", country="Ireland")
+length(IrishOaks)
+
+## ---- fig.width=4, fig.asp=.8-------------------------------------------------
+Bristle <- intcal.data.frames(intcal, taxon="Pinus longaeva")
+Bristle_yearly <- Bristle[[20]]$data[,c(8,14,15)]
+plot(Bristle_yearly[,1], Bristle_yearly[,2], xlab="cal BP", ylab="C14 BP")
+segments(Bristle_yearly[,1], Bristle_yearly[,2]-Bristle_yearly[,3], Bristle_yearly[,1], Bristle_yearly[,2]+Bristle_yearly[,3])
+
 ## -----------------------------------------------------------------------------
 mix.ccurves(0.4, cc1="IntCal20", cc2="Marine20", offset=c(100, 20))
 
